==> freesurfer-Linux-centos4-stable-pub-v4.0.0-full.tar.gz: freesurfer/lib/vtk/lib/vtk-5.1/vtkWidgetsKit.cmake <==
# Directory containing class headers.
SET(VTK_WIDGETS_HEADER_DIR "${VTK_INSTALL_PREFIX}/include/vtk-5.1")

# Classes in vtkWidgets.
SET(VTK_WIDGETS_CLASSES
  "vtk3DWidget"
  "vtkAbstractWidget"
  "vtkAffineRepresentation"
  "vtkAffineRepresentation2D"
  "vtkAffineWidget"
  "vtkAngleRepresentation"
  "vtkAngleRepresentation2D"
  "vtkAngleWidget"
  "vtkBalloonRepresentation"
  "vtkBalloonWidget"
  "vtkBezierContourLineInterpolator"
  "vtkBiDimensionalRepresentation2D"
  "vtkBiDimensionalWidget"
  "vtkBorderRepresentation"
  "vtkBorderWidget"
  "vtkBoundedPlanePointPlacer"
  "vtkBoxWidget"
  "vtkCameraRepresentation"
  "vtkCameraWidget"
  "vtkCaptionRepresentation"
  "vtkCaptionWidget"
  "vtkCenteredSliderWidget"
  "vtkContourLineInterpolator"
  "vtkContourRepresentation"
  "vtkFocalPlaneContourRepresentation"
  "vtkContourWidget"
  "vtkCheckerboardRepresentation"
  "vtkCheckerboardWidget"
  "vtkConstrainedPointHandleRepresentation"
  "vtkDistanceWidget"
  "vtkDistanceRepresentation"
  "vtkDistanceRepresentation2D"
  "vtkEvent"
  "vtkFocalPlanePointPlacer"
  "vtkHandleRepresentation"
  "vtkHandleWidget"
  "vtkHoverWidget"
  "vtkImageActorPointPlacer"
  "vtkImageOrthoPlanes"
  "vtkImagePlaneWidget"
  "vtkImageTracerWidget"
  "vtkImplicitPlaneRepresentation"
  "vtkImplicitPlaneWidget"
  "vtkImplicitPlaneWidget2"
  "vtkLineRepresentation"
  "vtkLineWidget"
  "vtkLineWidget2"
  "vtkLogoRepresentation"
  "vtkLogoWidget"
  "vtkOrientationMarkerWidget"
  "vtkOrientedGlyphContourRepresentation"
  "vtkOrientedGlyphFocalPlaneContourRepresentation"
  "vtkPlaneWidget"
  "vtkPlaybackRepresentation"
  "vtkPlaybackWidget"
  "vtkPointHandleRepresentation2D"
  "vtkPointHandleRepresentation3D"
  "vtkPointPlacer"
  "vtkPointWidget"
  "vtkPolyDataSourceWidget"
  "vtkPolyDataPointPlacer"
  "vtkPolygonalHandleRepresentation3D"
  "vtkPolygonalSurfacePointPlacer"
  "vtkPolyDataContourLineInterpolator"
  "vtkPolygonalSurfaceContourLineInterpolator"
  "vtkRectilinearWipeRepresentation"
  "vtkRectilinearWipeWidget"
  "vtkScalarBarWidget"
  "vtkSeedRepresentation"
  "vtkSeedWidget"
  "vtkSliderRepresentation"
  "vtkSliderRepresentation2D"
  "vtkSliderRepresentation3D"
  "vtkSliderWidget"
  "vtkSphereWidget"
  "vtkSplineWidget"
  "vtkTerrainDataPointPlacer"
  "vtkTerrainContourLineInterpolator"
  "vtkTextRepresentation"
  "vtkTextWidget"
  "vtkWidgetCallbackMapper"
  "vtkWidgetEvent"
  "vtkWidgetEventTranslator"
  "vtkWidgetRepresentation"
  "vtkXYPlotWidget")

# Abstract classes in vtkWidgets.
SET(VTK_WIDGETS_CLASSES_ABSTRACT
  "vtk3DWidget"
  "vtkAbstractWidget"
  "vtkAffineRepresentation"
  "vtkAngleRepresentation"
  "vtkContourLineInterpolator"
  "vtkContourRepresentation"
  "vtkFocalPlaneContourRepresentation"
  "vtkDistanceRepresentation"
  "vtkHandleRepresentation"
  "vtkPolyDataSourceWidget"
  "vtkPolyDataContourLineInterpolator"
  "vtkSliderRepresentation"
  "vtkWidgetRepresentation")

# Wrap-exclude classes in vtkWidgets.
SET(VTK_WIDGETS_CLASSES_WRAP_EXCLUDE)

# Set convenient variables to test each class.
FOREACH(class ${VTK_WIDGETS_CLASSES})
  SET(VTK_CLASS_EXISTS_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_WIDGETS_CLASSES_ABSTRACT})
  SET(VTK_CLASS_ABSTRACT_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_WIDGETS_CLASSES_WRAP_EXCLUDE})
  SET(VTK_CLASS_WRAP_EXCLUDE_${class} 1)
ENDFOREACH(class)

==> freesurfer-Linux-centos4-stable-pub-v4.3.0-full.tar.gz: freesurfer/lib/vtk/lib/vtk-5.2/vtkWidgetsKit.cmake <==
# Directory containing class headers.
SET(VTK_WIDGETS_HEADER_DIR "${VTK_INSTALL_PREFIX}/include/vtk-5.2")

# Classes in vtkWidgets.
SET(VTK_WIDGETS_CLASSES
  "vtk3DWidget"
  "vtkAbstractWidget"
  "vtkAffineRepresentation"
  "vtkAffineRepresentation2D"
  "vtkAffineWidget"
  "vtkAngleRepresentation"
  "vtkAngleRepresentation2D"
  "vtkAngleWidget"
  "vtkBalloonRepresentation"
  "vtkBalloonWidget"
  "vtkBezierContourLineInterpolator"
  "vtkBiDimensionalRepresentation2D"
  "vtkBiDimensionalWidget"
  "vtkBorderRepresentation"
  "vtkBorderWidget"
  "vtkBoundedPlanePointPlacer"
  "vtkBoxRepresentation"
  "vtkBoxWidget"
  "vtkBoxWidget2"
  "vtkCameraRepresentation"
  "vtkCameraWidget"
  "vtkCaptionRepresentation"
  "vtkCaptionWidget"
  "vtkCenteredSliderRepresentation"
  "vtkCenteredSliderWidget"
  "vtkContinuousValueWidget"
  "vtkContinuousValueWidgetRepresentation"
  "vtkContourLineInterpolator"
  "vtkContourRepresentation"
  "vtkFocalPlaneContourRepresentation"
  "vtkContourWidget"
  "vtkCheckerboardRepresentation"
  "vtkCheckerboardWidget"
  "vtkConstrainedPointHandleRepresentation"
  "vtkDistanceWidget"
  "vtkDistanceRepresentation"
  "vtkDistanceRepresentation2D"
  "vtkEllipsoidTensorProbeRepresentation"
  "vtkEvent"
  "vtkFocalPlanePointPlacer"
  "vtkHandleRepresentation"
  "vtkHandleWidget"
  "vtkHoverWidget"
  "vtkImageActorPointPlacer"
  "vtkImageOrthoPlanes"
  "vtkImagePlaneWidget"
  "vtkImageTracerWidget"
  "vtkImplicitPlaneRepresentation"
  "vtkImplicitPlaneWidget"
  "vtkImplicitPlaneWidget2"
  "vtkLineRepresentation"
  "vtkLineWidget"
  "vtkLineWidget2"
  "vtkLogoRepresentation"
  "vtkLogoWidget"
  "vtkOrientationMarkerWidget"
  "vtkOrientedGlyphContourRepresentation"
  "vtkOrientedGlyphFocalPlaneContourRepresentation"
  "vtkParallelopipedRepresentation"
  "vtkParallelopipedWidget"
  "vtkClosedSurfacePointPlacer"
  "vtkPlaneWidget"
  "vtkPlaybackRepresentation"
  "vtkPlaybackWidget"
  "vtkPointHandleRepresentation2D"
  "vtkPointHandleRepresentation3D"
  "vtkPointPlacer"
  "vtkPointWidget"
  "vtkPolyDataSourceWidget"
  "vtkPolyDataPointPlacer"
  "vtkPolygonalHandleRepresentation3D"
  "vtkPolygonalSurfacePointPlacer"
  "vtkPolyDataContourLineInterpolator"
  "vtkPolygonalSurfaceContourLineInterpolator"
  "vtkRectilinearWipeRepresentation"
  "vtkRectilinearWipeWidget"
  "vtkScalarBarRepresentation"
  "vtkScalarBarWidget"
  "vtkSeedRepresentation"
  "vtkSeedWidget"
  "vtkSliderRepresentation"
  "vtkSliderRepresentation2D"
  "vtkSliderRepresentation3D"
  "vtkSliderWidget"
  "vtkSphereHandleRepresentation"
  "vtkSphereRepresentation"
  "vtkSphereWidget"
  "vtkSphereWidget2"
  "vtkSplineWidget"
  "vtkTensorProbeWidget"
  "vtkTensorProbeRepresentation"
  "vtkTerrainDataPointPlacer"
  "vtkTerrainContourLineInterpolator"
  "vtkTextRepresentation"
  "vtkTextWidget"
  "vtkWidgetCallbackMapper"
  "vtkWidgetEvent"
  "vtkWidgetEventTranslator"
  "vtkWidgetRepresentation"
  "vtkWidgetSet"
  "vtkXYPlotWidget")

# Abstract classes in vtkWidgets.
SET(VTK_WIDGETS_CLASSES_ABSTRACT
  "vtk3DWidget"
  "vtkAbstractWidget"
  "vtkAffineRepresentation"
  "vtkAngleRepresentation"
  "vtkContinuousValueWidget"
  "vtkContinuousValueWidgetRepresentation"
  "vtkContourLineInterpolator"
  "vtkContourRepresentation"
  "vtkFocalPlaneContourRepresentation"
  "vtkDistanceRepresentation"
  "vtkHandleRepresentation"
  "vtkPolyDataSourceWidget"
  "vtkPolyDataContourLineInterpolator"
  "vtkSliderRepresentation"
  "vtkTensorProbeRepresentation"
  "vtkWidgetRepresentation")

# Wrap-exclude classes in vtkWidgets.
SET(VTK_WIDGETS_CLASSES_WRAP_EXCLUDE)

# Set convenient variables to test each class.
FOREACH(class ${VTK_WIDGETS_CLASSES})
  SET(VTK_CLASS_EXISTS_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_WIDGETS_CLASSES_ABSTRACT})
  SET(VTK_CLASS_ABSTRACT_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_WIDGETS_CLASSES_WRAP_EXCLUDE})
  SET(VTK_CLASS_WRAP_EXCLUDE_${class} 1)
ENDFOREACH(class)
